/*
 * 本範程式為Arduino非接觸式測溫器的範例
 * 以單顆MLX90615配合0.91吋OLED的完成，由傑森創工提供
 * 本程式可用在單顆MLX90615或是MLX90615模組
 * 
 * 請先安裝MLX90615函式庫
 * 下載網址：https://github.com/skiselev/MLX90615
 * 
 * 粉絲團：https://www.facebook.com/jasonshow
 * 傑森創工購物網：https://www.jmaker.com.tw/
 * 傑森創工部落格：https://blog.jmaker.com.tw/
 */
 
#include <Wire.h>
#include <mlx90615.h>
#include <SPI.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128 // OLED 寬度像素
#define SCREEN_HEIGHT 32 // OLED 高度像素

// 設定OLED
#define OLED_RESET     4 // Reset pin # (or -1 if sharing Arduino reset pin)
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

MLX90615 mlx = MLX90615();

void setup() {
  Serial.begin(9600);

  // 偵測是否安裝好OLED了
  if(!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { // Address 0x3C for 128x32
    Serial.println(F("SSD1306 allocation failed"));
    for(;;); // Don't proceed, loop forever
  }
  
  display.clearDisplay();
  display.setRotation(2);             //OLED顯示轉向，可自行決定方向
  display.setTextSize(4);             // 設定文字大小
  display.setTextColor(1);           // 1:OLED預設的顏色(這個會依該OLED的顏色來決定)
  display.setCursor(0,0);             // Start at top-left corner
  display.print("Hello~");
  display.display();
  delay(1000);

  //起始MLX90615
  Serial.println("MLX90615 infra-red temperature sensor test");
  mlx.begin();
  Serial.print("Sensor ID number = ");
  Serial.println(mlx.get_id(), HEX);
}

void loop() {
  Serial.print("Ambient = ");
  Serial.print(mlx.get_ambient_temp()); //環境溫度
  Serial.print(" *C\tObject = ");
  Serial.print(mlx.get_object_temp());  //被偵測物體溫度，OLED只顯示這個數值
  Serial.println(" *C");

  display.clearDisplay();
  display.setTextSize(4);             
   display.setTextColor(1);        
  display.setCursor(0,4);             
  display.print(mlx.get_object_temp(),1); //顯示被偵測物體溫度，取到小數點1位

  //以下是顯示度C的文字
  display.setTextSize(2);
  display.setCursor(99,0); 
  display.print("o");
  display.setTextSize(3);
  display.setCursor(109,12); 
  display.print("C");
  display.display();
  delay(500);
}
